==> alfresco-remote-api-16.35-sources.jar: org/alfresco/rest/framework/core/exceptions/WebScriptExceptionResolver.java <==
/*
 * #%L
 * Alfresco Remote API
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.rest.framework.core.exceptions;

import org.springframework.extensions.webscripts.WebScriptException;

import javax.servlet.http.HttpServletResponse;

/**
 * Resolves WebScriptExceptions
 *
 * @author Gethin James
 */
public class WebScriptExceptionResolver implements ExceptionResolver<WebScriptException> {

    @Override
    public ErrorResponse resolveException(WebScriptException ex) {
        return new ErrorResponse(DefaultExceptionResolver.DEFAULT_MESSAGE_ID, ex.getStatus(), ex.getLocalizedMessage(), ex.getStackTrace(), null);
    }
}

==> alfresco-remote-api-23.3.21.2-sources.jar: org/alfresco/rest/framework/core/exceptions/WebScriptExceptionResolver.java <==
/*
 * #%L
 * Alfresco Remote API
 * %%
 * Copyright (C) 2005 - 2023 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.rest.framework.core.exceptions;

import org.springframework.extensions.webscripts.WebScriptException;

import jakarta.servlet.http.HttpServletResponse;

/**
 * Resolves WebScriptExceptions
 *
 * @author Gethin James
 */
public class WebScriptExceptionResolver implements ExceptionResolver<WebScriptException> {

    @Override
    public ErrorResponse resolveException(WebScriptException ex) {
        return new ErrorResponse(DefaultExceptionResolver.DEFAULT_MESSAGE_ID, ex.getStatus(), ex.getLocalizedMessage(), ex.getStackTrace(), null);
    }
}
